using ComputerShopContracts.BindingModels;
using ComputerShopContracts.BusinessLogicContracts;
using ComputerShopContracts.SearchModels;
using ComputerShopContracts.ViewModels;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ComputerShopBusinessLogic.BusinessLogics
{
    public class OrderLogic : IOrderLogic
    {
        public bool CreateOrder(OrderBindingModel model)
        {
            throw new NotImplementedException();
        }

        public bool Delete(ComponentBindingModel model)
        {
            throw new NotImplementedException();
        }

        public bool DeliveryOrder(OrderBindingModel model)
        {
            throw new NotImplementedException();
        }

        public bool FinishOrder(OrderBindingModel model)
        {
            throw new NotImplementedException();
        }

        public OrderViewModel? ReadElement(OrderSearchModel model)
        {
            throw new NotImplementedException();
        }

        public List<OrderViewModel>? ReadList(OrderSearchModel? model)
        {
            throw new NotImplementedException();
        }

        public bool TakeOrderInWork(OrderBindingModel model)
        {
            throw new NotImplementedException();
        }

        public bool Update(ComponentBindingModel model)
        {
            throw new NotImplementedException();
        }
    }
}
